Mopidy-Podcast
========================================================================

Mopidy-Podcast is a Mopidy_ extension for searching and browsing
podcasts.


Installation
------------------------------------------------------------------------

Like other Mopidy extensions, Mopidy-Podcast can be installed using
pip by running::

    pip install Mopidy-Podcast

You can also download and install Debian/Ubuntu packages for
Mopidy-Podcast releases_.


Project Resources
------------------------------------------------------------------------

- `Documentation`_
- `Issue Tracker`_
- `Source Code`_
- `Change Log`_
- `Development Snapshot`_

.. image:: https://pypip.in/v/Mopidy-Podcast/badge.png
    :target: https://pypi.python.org/pypi/Mopidy-Podcast/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/Mopidy-Podcast/badge.png
    :target: https://pypi.python.org/pypi/Mopidy-Podcast/
    :alt: Number of PyPI downloads


License
------------------------------------------------------------------------

Copyright (c) 2014 Thomas Kemmer.

Licensed under the `Apache License, Version 2.0`_.


.. _Mopidy: http://www.mopidy.com/
.. _releases: https://github.com/tkem/mopidy-podcast/releases
.. _Documentation: http://mopidy-podcast.readthedocs.org/en/latest/
.. _Issue Tracker: https://github.com/tkem/mopidy-podcast/issues/
.. _Source Code: https://github.com/tkem/mopidy-podcast
.. _Change Log: http://raw.github.com/tkem/mopidy-podcast/master/Changes
.. _Development Snapshot: https://github.com/tkem/mopidy-podcast/tarball/master#egg=Mopidy-Podcast-dev
.. _Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0
